Wikipedia, the free encyclopedia

# Main Page

From Wikipedia, the free encyclopedia

Welcome to Wikipedia, the free encyclopedia that anyone can edit. 4,663,771 articles in English
| Arts Biography Geography | History Mathematics Science | Society Technology All portals

## From today's featured article
Greed is a 1924 American silent film, written and directed by Erich von Stroheim and based on Frank Norris's novel McTeague. The film depicts three protagonists who succumb to their darker nature over a mutual desire for a lottery prize of $5,000 in gold (screenshot pictured). Von Stroheim shot more than 85 hours of footage, using sophisticated techniques such as deep-focus cinematography and montage editing, and obsessed over accuracy during production. Greed was one of the few films of its time to be shot entirely on location. Two months were spent shooting in Death Valley for the final sequence and many of the cast and crew became ill. Originally almost eight hours long, Greed was edited against von Stroheim's wishes to about two-and-a-half hours by Metro-Goldwyn-Mayer studio heads Irving Thalberg and Louis B. Mayer. The cut footage is lost, and still sought after by film archivists and historians. Numerous false claims of the original version's discovery have been made over the years. In 1999, a reconstructed four-hour version was released using surviving stills from the lost footage. (Full article...) Recently featured: Tammar wallaby – John Barbirolli – Carsten Borchgrevink Archive – By email – More featured articles...
## Did you know...
From Wikipedia's new and recently improved content: ... that Loboc Church (pictured) was patterned after San Ignacio Church in Intramuros? ... that the Sigma Coronae Borealis star system is composed of three sun-like stars and two red dwarfs? ... that the opening track from Le Tigre's debut album Le Tigre modifies the titular question from "Who Put the Bomp (in the Bomp, Bomp, Bomp)"? ... that the Fort of Justices was built as a reaction to a possible German invasion, resulting in the simplicity of the buildings? ... that in his autobiography With the Century, North Korean dictator Kim Il-sung stated that his motto is "The people are my God"? ... that Christine's margareta rat was named after a member of the expedition that discovered it in 2011? ... that television critic Marvin Kitman co-authored a book with George Washington? Archive – Start a new article – Nominate an article
## In the news
In Canadian football, the Calgary Stampeders defeat the Hamilton Tiger-Cats to win the Grey Cup. Australian Test cricketer Phillip Hughes (pictured) dies after being struck in the neck by a ball bowled to him. A previously unknown copy of the First Folio of Shakespeare's plays, dated to 1623, is discovered at a library in Saint-Omer, near Calais, France. Renewed rioting breaks out in Ferguson, Missouri, and protests occur across the United States, after a grand jury returns no indictment in the case of an unarmed suspect's fatal shooting by a police officer. Magnus Carlsen defeats Viswanathan Anand to retain the World Chess Championship title. Ongoing: Ebola outbreak – Islamic State of Iraq and the Levant Recent deaths: Jean Béliveau – Go Seigen – Mark Strand
## On this day...
December 4: Navy Day in India 1829 – Sati, the Hindu funeral custom of widows immolating themselves, was prohibited in part of British India after years of campaigning by Ram Mohan Roy. 1893 – First Matabele War: A patrol of British South Africa Company soldiers was ambushed and annihilated by more than 3,000 Matabele warriors. 1909 – The Montreal Canadiens, the oldest professional ice hockey club in the world, was founded as a charter member of the National Hockey Association. 1954 – The global hamburger fast food chain Burger King, known for its signature item the Whopper (pictured), was founded in Miami, Florida, US. 1971 – The Troubles: The Ulster Volunteer Force, an Ulster loyalist paramilitary group, exploded a bomb at a Catholic-owned pub in Belfast, Northern Ireland, killing 15 people. More anniversaries: December 3 – December 4 – December 5 Archive – By email – List of historical anniversaries It is now December 4, 2014 (UTC) – Reload this page

## Today's featured picture
The Guyou hemisphere-in-a-square projection is a map projection used to project a hemisphere. It is conformal everywhere except for the four corners of each hemisphere's square. This projection, developed by Émile Guyou in 1887, can be considered an oblique aspect of the Peirce quincuncial projection, with which it has numerous similarities. The imagery used for the map is a derivative of NASA's Blue Marble summer months composite, with oceans lightened to enhance legibility and contrast. Map: Strebe, using Geocart Recently featured: Gilbert Stuart – Buller's albatross – Veined rapa whelk Archive – More featured pictures...

## Other areas of Wikipedia

- Community portal – Bulletin board, projects, resources and activities covering a wide range of Wikipedia areas.
- Help desk – Ask questions about using Wikipedia.
- Local embassy – For Wikipedia-related communication in languages other than English.
- Reference desk – Serving as virtual librarians, Wikipedia volunteers tackle your questions on a wide range of subjects.
- Site news – Announcements, updates, articles and press releases on Wikipedia and the Wikimedia Foundation.
- Village pump – For discussions about Wikipedia itself, including areas for technical issues and policies.

## Wikipedia's sister projects

Wikipedia is hosted by the Wikimedia Foundation, a non-profit organization that also hosts a range of other projects:

| Commons Free media repository |  | MediaWiki Wiki software development |  | Meta-Wiki Wikimedia project coordination
| Wikibooks Free textbooks and manuals |  | Wikidata Free knowledge base |  | Wikinews Free-content news
| Wikiquote Collection of quotations |  | Wikisource Free-content library |  | Wikispecies Directory of species
| Wikiversity Free learning materials and activities |  | Wikivoyage Free travel guide |  | Wiktionary Dictionary and thesaurus

## Wikipedia languages

This Wikipedia is written in English. Started in 2001 (2001), it currently contains 4,663,771 articles. Many other Wikipedias are available; some of the largest are listed below.

- More than 1,000,000 articles:
  - Deutsch
  - español
  - français
  - italiano
  - Nederlands
  - polski
  - русский
  - svenska
- More than 400,000 articles:
  - català
  - فارسی
  - 日本語
  - norsk bokmål
  - português
  - Tiếng Việt
  - українська
  - 中文
- More than 200,000 articles:
  - العربية
  - Bahasa Indonesia
  - Bahasa Melayu
  - čeština
  - Esperanto
  - euskara
  - 한국어
  - magyar
  - română
  - српски / srpski
  - suomi
  - Türkçe
- More than 50,000 articles:
  - български
  - dansk
  - eesti
  - Ελληνικά
  - English (simple)
  - galego
  - עברית
  - hrvatski
  - latviešu
  - lietuvių
  - norsk nynorsk
  - slovenčina
  - slovenščina
  - srpskohrvatski / српскохрватски
  - ไทย

Complete list of Wikipedias
Retrieved from "http://en.wikipedia.org/w/index.php?title=Main_Page&oldid=615503846"